package Acme::MyFirstModule::WWILLIS;

use warnings;
use strict;

=head1 NAME

Acme::MyFirstModule::WWILLIS - The great old Acme::MyFirstModule::WWILLIS!

=head1 VERSION

Version 0.03

=cut
our $VERSION = '0.03';

=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use Acme::MyFirstModule::WWILLIS;

    my $foo = Acme::MyFirstModule::WWILLIS->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 FUNCTIONS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
}

=head1 AUTHOR

Will Willis, C<< <wwillis at cpan.org> >>

=head1 BUGS

Yes, very likely.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Acme::MyFirstModule::WWILLIS

You can also look for information at:

=over 4

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Acme-MyFirstModule-WWILLIS>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Acme-MyFirstModule-WWILLIS>

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-MyFirstModule-WWILLIS>

=item * Search CPAN

L<http://search.cpan.org/dist/Acme-MyFirstModule-WWILLIS>

=back

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT & LICENSE

Copyright 2023 Will Willis, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of Acme::MyFirstModule::WWILLIS
